==> selva-0.3.0-py3-none-any.whl: selva/web/routing/path_converter_impl.py <==
from pathlib import PurePath

from selva.di.decorators import service
from selva.web.errors import NotFoundError
from selva.web.routing.path_converter import PathConverter


@service(provides=PathConverter[str])
class StrPathConverter:
    def from_path(self, value: str) -> str:
        return value

    def into_path(self, obj: str) -> str:
        return obj


@service(provides=PathConverter[int])
class IntPathConverter:
    def from_path(self, value: str) -> int | None:
        try:
            return int(value)
        except ValueError:
            raise NotFoundError()

    def into_path(self, obj: int) -> str:
        return str(obj)


@service(provides=PathConverter[float])
class FloatPathConverter:
    def from_path(self, value: str) -> float | None:
        try:
            return float(value)
        except ValueError:
            raise NotFoundError()

    def into_path(self, obj: float) -> str:
        return str(obj)


@service(provides=PathConverter[bool])
class BoolPathConverter:
    TRUE_VALUES = ["1", "true", "True", "TRUE"]
    FALSE_VALUES = ["0", "false", "False", "FALSE"]
    POSSIBLE_VALUE = TRUE_VALUES + FALSE_VALUES

    def from_path(self, value: str) -> bool | None:
        if value in self.POSSIBLE_VALUE:
            return value in self.TRUE_VALUES

        raise NotFoundError()

    def into_path(self, obj: bool) -> str:
        return str(obj)


@service(provides=PathConverter[PurePath])
class PurePathPathConverter:
    def from_path(self, value: str) -> PurePath:
        return PurePath(value)

    def into_path(self, obj: PurePath) -> str:
        return obj.as_posix()

==> selva-0.3.1-py3-none-any.whl: selva/web/routing/path_converter_impl.py <==
from pathlib import PurePath

from selva.di.decorators import service
from selva.web.errors import HttpNotFoundError
from selva.web.routing.path_converter import PathConverter


@service(provides=PathConverter[str])
class StrPathConverter:
    def from_path(self, value: str) -> str:
        return value

    def into_path(self, obj: str) -> str:
        return obj


@service(provides=PathConverter[int])
class IntPathConverter:
    def from_path(self, value: str) -> int | None:
        try:
            return int(value)
        except ValueError:
            raise HttpNotFoundError()

    def into_path(self, obj: int) -> str:
        return str(obj)


@service(provides=PathConverter[float])
class FloatPathConverter:
    def from_path(self, value: str) -> float | None:
        try:
            return float(value)
        except ValueError:
            raise HttpNotFoundError()

    def into_path(self, obj: float) -> str:
        return str(obj)


@service(provides=PathConverter[bool])
class BoolPathConverter:
    TRUE_VALUES = ["1", "true", "True", "TRUE"]
    FALSE_VALUES = ["0", "false", "False", "FALSE"]
    POSSIBLE_VALUE = TRUE_VALUES + FALSE_VALUES

    def from_path(self, value: str) -> bool | None:
        if value in self.POSSIBLE_VALUE:
            return value in self.TRUE_VALUES

        raise HttpNotFoundError()

    def into_path(self, obj: bool) -> str:
        return str(obj)


@service(provides=PathConverter[PurePath])
class PurePathPathConverter:
    def from_path(self, value: str) -> PurePath:
        return PurePath(value)

    def into_path(self, obj: PurePath) -> str:
        return obj.as_posix()
